@@ -13,7 +13,7 @@ import (
 	"github.com/anchore/grype/grype/pkg/qualifier"
 	"github.com/anchore/grype/grype/version"
 	"github.com/anchore/grype/grype/vulnerability"
-	syftPkg "github.com/anchore/syft/syft/pkg"
+	"github.com/anchore/syft/syft/cpe"
 )
 
 func Test_GetByDistro(t *testing.T) {
@@ -37,7 +37,7 @@ func Test_GetByDistro(t *testing.T) {
 			ID:                "CVE-2014-fake-1",
 			Namespace:         "debian:distro:debian:8",
 			PackageQualifiers: []qualifier.Qualifier{},
-			CPEs:              []syftPkg.CPE{},
+			CPEs:              []cpe.CPE{},
 			Advisories:        []vulnerability.Advisory{},
 		},
 		{
@@ -45,7 +45,7 @@ func Test_GetByDistro(t *testing.T) {
 			ID:                "CVE-2013-fake-2",
 			Namespace:         "debian:distro:debian:8",
 			PackageQualifiers: []qualifier.Qualifier{},
-			CPEs:              []syftPkg.CPE{},
+			CPEs:              []cpe.CPE{},
 			Advisories:        []vulnerability.Advisory{},
 		},
 	}
@@ -74,30 +74,23 @@ func Test_GetByDistro_nilDistro(t *testing.T) {
 	assert.NoError(t, err)
 }
 
-func must(c syftPkg.CPE, e error) syftPkg.CPE {
-	if e != nil {
-		panic(e)
-	}
-	return c
-}
-
 func Test_GetByCPE(t *testing.T) {
 
 	tests := []struct {
 		name     string
-		cpe      syftPkg.CPE
+		cpe      cpe.CPE
 		expected []vulnerability.Vulnerability
 		err      bool
 	}{
 		{
 			name: "match from name and target SW",
-			cpe:  must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:ruby:*:*")),
+			cpe:  cpe.Must("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:ruby:*:*"),
 			expected: []vulnerability.Vulnerability{
 				{
 					Constraint: version.MustGetConstraint("< 3.7.4", version.UnknownFormat),
 					ID:         "CVE-2014-fake-4",
-					CPEs: []syftPkg.CPE{
-						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
+					CPEs: []cpe.CPE{
+						cpe.Must("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*"),
 					},
 					Namespace:         "nvd:cpe",
 					PackageQualifiers: []qualifier.Qualifier{},
@@ -107,13 +100,13 @@ func Test_GetByCPE(t *testing.T) {
 		},
 		{
 			name: "match with normalization",
-			cpe:  must(syftPkg.NewCPE("cpe:2.3:*:ActiVERecord:ACTiveRecord:*:*:*:*:*:ruby:*:*")),
+			cpe:  cpe.Must("cpe:2.3:*:ActiVERecord:ACTiveRecord:*:*:*:*:*:ruby:*:*"),
 			expected: []vulnerability.Vulnerability{
 				{
 					Constraint: version.MustGetConstraint("< 3.7.4", version.UnknownFormat),
 					ID:         "CVE-2014-fake-4",
-					CPEs: []syftPkg.CPE{
-						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
+					CPEs: []cpe.CPE{
+						cpe.Must("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*"),
 					},
 					Namespace:         "nvd:cpe",
 					PackageQualifiers: []qualifier.Qualifier{},
@@ -123,13 +116,13 @@ func Test_GetByCPE(t *testing.T) {
 		},
 		{
 			name: "match from vendor & name",
-			cpe:  must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:*:*:*")),
+			cpe:  cpe.Must("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:*:*:*"),
 			expected: []vulnerability.Vulnerability{
 				{
 					Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
 					ID:         "CVE-2014-fake-3",
-					CPEs: []syftPkg.CPE{
-						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*")),
+					CPEs: []cpe.CPE{
+						cpe.Must("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 					},
 					Namespace:         "nvd:cpe",
 					PackageQualifiers: []qualifier.Qualifier{},
@@ -138,8 +131,8 @@ func Test_GetByCPE(t *testing.T) {
 				{
 					Constraint: version.MustGetConstraint("< 3.7.4", version.UnknownFormat),
 					ID:         "CVE-2014-fake-4",
-					CPEs: []syftPkg.CPE{
-						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
+					CPEs: []cpe.CPE{
+						cpe.Must("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*"),
 					},
 					Namespace:         "nvd:cpe",
 					PackageQualifiers: []qualifier.Qualifier{},
@@ -150,7 +143,7 @@ func Test_GetByCPE(t *testing.T) {
 
 		{
 			name: "dont allow any name",
-			cpe:  must(syftPkg.NewCPE("cpe:2.3:*:couldntgetthisrightcouldyou:*:*:*:*:*:*:*:*:*")),
+			cpe:  cpe.Must("cpe:2.3:*:couldntgetthisrightcouldyou:*:*:*:*:*:*:*:*:*"),
 			err:  true,
 		},
 	}
@@ -193,7 +186,7 @@ func Test_Get(t *testing.T) {
 			ID:                "CVE-2014-fake-1",
 			Namespace:         "debian:distro:debian:8",
 			PackageQualifiers: []qualifier.Qualifier{},
-			CPEs:              []syftPkg.CPE{},
+			CPEs:              []cpe.CPE{},
 			Advisories:        []vulnerability.Advisory{},
 		},
 	}
