@@ -248,11 +248,10 @@ func TestMatcherRpm(t *testing.T) {
 		{
 			name: "package with modularity label 1",
 			p: pkg.Package{
-				ID:           pkg.ID(uuid.NewString()),
-				Name:         "maniac",
-				Version:      "0.1",
-				Type:         syftPkg.RpmPkg,
-				MetadataType: pkg.RpmMetadataType,
+				ID:      pkg.ID(uuid.NewString()),
+				Name:    "maniac",
+				Version: "0.1",
+				Type:    syftPkg.RpmPkg,
 				Metadata: pkg.RpmMetadata{
 					ModularityLabel: "containertools:3:1234:5678",
 				},
@@ -276,11 +275,10 @@ func TestMatcherRpm(t *testing.T) {
 		{
 			name: "package with modularity label 2",
 			p: pkg.Package{
-				ID:           pkg.ID(uuid.NewString()),
-				Name:         "maniac",
-				Version:      "0.1",
-				Type:         syftPkg.RpmPkg,
-				MetadataType: pkg.RpmMetadataType,
+				ID:      pkg.ID(uuid.NewString()),
+				Name:    "maniac",
+				Version: "0.1",
+				Type:    syftPkg.RpmPkg,
 				Metadata: pkg.RpmMetadata{
 					ModularityLabel: "containertools:1:abc:123",
 				},
@@ -303,11 +301,10 @@ func TestMatcherRpm(t *testing.T) {
 		{
 			name: "package without modularity label",
 			p: pkg.Package{
-				ID:           pkg.ID(uuid.NewString()),
-				Name:         "maniac",
-				Version:      "0.1",
-				Type:         syftPkg.RpmPkg,
-				MetadataType: pkg.RpmMetadataType,
+				ID:      pkg.ID(uuid.NewString()),
+				Name:    "maniac",
+				Version: "0.1",
+				Type:    syftPkg.RpmPkg,
 			},
 			setup: func() (vulnerability.Provider, *distro.Distro, Matcher) {
 				matcher := Matcher{}
