@@ -100,6 +100,15 @@ func newMockDbStore() *mockStore {
 					},
 				},
 			},
+			"github:language:idris": {
+				"my-package": []grypeDB.Vulnerability{
+					{
+						ID:                "CVE-bogus-my-package-2-idris",
+						VersionConstraint: "< 2.0",
+						VersionFormat:     "unknown",
+					},
+				},
+			},
 			"github:language:javascript": {
 				"npm": []grypeDB.Vulnerability{
 					{
@@ -117,13 +126,6 @@ func newMockDbStore() *mockStore {
 						VersionFormat:     "python",
 					},
 				},
-				"my-package": []grypeDB.Vulnerability{
-					{
-						ID:                "CVE-bogus-my-package-2-python",
-						VersionConstraint: "< 2.0",
-						VersionFormat:     "python",
-					},
-				},
 			},
 			"github:language:ruby": {
 				"bundler": []grypeDB.Vulnerability{
@@ -161,6 +163,22 @@ func newMockDbStore() *mockStore {
 					},
 				},
 			},
+			"github:language:rust": {
+				"hello-auditable": []grypeDB.Vulnerability{
+					{
+						ID:                "CVE-rust-sample-1",
+						VersionConstraint: "< 0.2.0",
+						VersionFormat:     "unknown",
+					},
+				},
+				"auditable": []grypeDB.Vulnerability{
+					{
+						ID:                "CVE-rust-sample-2",
+						VersionConstraint: "< 0.2.0",
+						VersionFormat:     "unknown",
+					},
+				},
+			},
 			"debian:distro:debian:8": {
 				"apt-dev": []grypeDB.Vulnerability{
 					{
